handleBackPress method
Invokes the most recently registered handler, if any, and reports whether one was found.
Implementation
bool handleBackPress() {
if (_backHandlers.isEmpty) return false;
_backHandlers.last();
return true;
}
Invokes the most recently registered handler, if any, and reports whether one was found.
bool handleBackPress() {
if (_backHandlers.isEmpty) return false;
_backHandlers.last();
return true;
}