FrameSampleStore class

Bounded, FIFO ring buffer of captured FrameSamples.

Inheritance

Constructors

FrameSampleStore({int maxEntries = 300})

Properties

currentFps double
Average FPS over the most recent window samples (~1s at 60Hz).
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
lastRssBytes int?
Approximate resident set size in bytes, if available on this platform; pushed in periodically from outside this store.
getter/setter pair
maxEntries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samples List<FrameSample>
no setter

Methods

add(FrameSample sample) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
recentJankyCount({int window = 60}) int
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setRssBytes(int? bytes) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited