lastRssBytes property
Approximate resident set size in bytes, if available on this platform; pushed in periodically from outside this store.
Implementation
int? lastRssBytes;
Approximate resident set size in bytes, if available on this platform; pushed in periodically from outside this store.
int? lastRssBytes;