NetworkEvent class

A single captured HTTP request/response (or error) exchange.

Constructors

NetworkEvent({required String id, required String method, required String url, required DateTime startedAt, Map<String, String> queryParameters = const {}, Map<String, String> requestHeaders = const {}, Object? requestBody})

Properties

completedAt DateTime?
getter/setter pair
duration Duration?
no setter
errorMessage String?
getter/setter pair
errorType String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
isError bool
no setter
isPending bool
no setter
method String
final
queryParameters Map<String, String>
final
requestBody Object?
final
requestHeaders Map<String, String>
final
responseBody Object?
getter/setter pair
responseHeaders Map<String, String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final
statusCode int?
getter/setter pair
statusMessage String?
getter/setter pair
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited