onMinimize property
Minimizes the panel to a small floating window instead of closing
it outright — see DevToolsFloatingWindow.
Implementation
final VoidCallback onMinimize;
Minimizes the panel to a small floating window instead of closing
it outright — see DevToolsFloatingWindow.
final VoidCallback onMinimize;