BundleScanResult class

The result of scanning the running app's own installed bundle on disk, from app_bundle_scan.dart.

Constructors

BundleScanResult({required SizeAnalysisNode root, required String platformLabel})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
platformLabel String
Platform.operatingSystem at scan time — ios, macos, windows, or linux.
final
root SizeAnalysisNode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited