currentRssBytes function
Current resident set size in bytes, or null if unavailable.
Implementation
int? currentRssBytes() {
try {
return ProcessInfo.currentRss;
} catch (_) {
return null;
}
}
Current resident set size in bytes, or null if unavailable.
int? currentRssBytes() {
try {
return ProcessInfo.currentRss;
} catch (_) {
return null;
}
}