CorextraException class abstract

Base class for all custom exceptions in the package.

Implemented types
Implementers

Constructors

CorextraException({required String message, String? code, Map<String, dynamic>? details})
const

Properties

code → String?
final
details → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited