ListExtensions<T> extension

Extensions on nullable List for safe emptiness checks.

on

Properties

isNotNullOrEmpty bool

Available on List<T>?, provided by the ListExtensions extension

Returns true if the list is not null and contains at least one element.
no setter
isNullOrEmpty bool

Available on List<T>?, provided by the ListExtensions extension

Returns true if the list is null or empty.
no setter