isLandscape property
bool
get
isLandscape
Returns true if the screen is in landscape orientation.
Implementation
bool get isLandscape => screenOrientation == Orientation.landscape;
Returns true if the screen is in landscape orientation.
bool get isLandscape => screenOrientation == Orientation.landscape;