ResponsiveBreakpoints class

Provides helpers to check screen size categories for responsive layouts.

Constructors

ResponsiveBreakpoints()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

lg ↔ double
getter/setter pair
md ↔ double
getter/setter pair
sm ↔ double
getter/setter pair
xl ↔ double
getter/setter pair
xxl ↔ double
getter/setter pair

Static Methods

deviceType(BoxConstraints constraints) → DeviceType
deviceTypeOf the width read from BoxConstraints.
deviceTypeContext(BuildContext context) → DeviceType
deviceTypeOf the width read from BuildContext.
deviceTypeOf(double width) → DeviceType
Classifies width as DeviceType.mobile, DeviceType.tablet or DeviceType.desktop.
isLg(BoxConstraints constraints) → bool
Returns true if width from BoxConstraints is ≥ lg.
isLgContext(BuildContext context) → bool
Returns true if width from BuildContext is ≥ lg.
isMd(BoxConstraints constraints) → bool
Returns true if width from BoxConstraints is ≥ md.
isMdContext(BuildContext context) → bool
Returns true if width from BuildContext is ≥ md.
isSm(BoxConstraints constraints) → bool
Returns true if width from BoxConstraints is ≥ sm.
isSmContext(BuildContext context) → bool
Returns true if width from BuildContext is ≥ sm.
isXl(BoxConstraints constraints) → bool
Returns true if width from BoxConstraints is ≥ xl.
isXlContext(BuildContext context) → bool
Returns true if width from BuildContext is ≥ xl.
isXxl(BoxConstraints constraints) → bool
Returns true if width from BoxConstraints is ≥ xxl.
isXxlContext(BuildContext context) → bool
Returns true if width from BuildContext is ≥ xxl.
setCustomBreakpoints({double? sm, double? md, double? lg, double? xl, double? xxl}) → void
Override default breakpoints. All parameters are optional.
valueOf<T>(double width, {required T base, T? sm, T? md, T? lg, T? xl, T? xxl}) → T
Returns the highest-matching size-specific value for width, or base if none match.
when<T>(BoxConstraints constraints, {required T base(), T smBuilder()?, T mdBuilder()?, T lgBuilder()?, T xlBuilder()?, T xxlBuilder()?}) → T
Returns a value depending on the current screen width.