commitThreshold property
How far past the edge a drag has to be released — as a fraction of
the available peek travel (size.width - peekExtent) — to commit
to fully peeking rather than springing back to flush-at-the-edge.
Implementation
final double commitThreshold;