ListExtensions<T> extension
Extensions on nullable List for safe emptiness checks.
- on
-
- List<
T> ?
- List<
Properties
- isNotNullOrEmpty → bool
-
Available on List<
Returns true if the list is not null and contains at least one element.T> ?, provided by the ListExtensions extensionno setter - isNullOrEmpty → bool
-
Available on List<
Returns true if the list is null or empty.T> ?, provided by the ListExtensions extensionno setter